******************************************************************************************************
*DO FILE FOR: Nishitateno, Shuhei and Burke, Paul J. 2014. The Motorcycle Kuznets Curve. Journal of Transport Geography 36: 116-123.
******************************************************************************************************
clear
use Nishitateno_Burke_2014.dta
set more off
describe
encode code, gen(cc)

*As noted in the Appendix, we have removed some motorcycle country-year observations with apparent errors.
*For queries, please contact the authors.
	
******************************************************************************************************
*VARIABLE CONSTRUCTION
******************************************************************************************************
	gen moto_pth=1000*motorcycles/(pop*1000000)
	replace moto_pth=1000*motorcycles/population if moto_pth==.
	gen lnmoto_pth=ln(moto_pth)
	
	gen veh_pth=1000*othermotorvehicles/(pop*1000000)
	replace veh_pth=1000*othermotorvehicles/population if veh_pth==.
	gen lnveh_pth=ln(veh_pth)
	
	gen lntotalveh_pth=ln(moto_pth+veh_pth)
	
	gen car_pth=1000*cars/(pop*1000000)
	replace car_pth=1000*cars/population if car_pth==.
	gen lncar_pth=ln(car_pth)
	
	gen bus_pth=1000*buses/(pop*1000000)
	replace bus_pth=1000*buses/population if bus_pth==.
	gen lnbus_pth=ln(bus_pth)
	
	gen trucks_pth=1000*trucks/(pop*1000000)
	replace trucks_pth=1000*trucks/population if trucks_pth==.
	gen lntrucks_pth=ln(trucks_pth)	
	
	gen moto_share=motorcycles/(othermotorvehicles+motorcycles)*100
	
	gen lngdp_pc=ln(rgdpe/pop)
	gen lngdp_pcsq=(lngdp_pc)^2
	gen lnpopden=ln(popdensity)
	gen lngdp_pc_int=lngdp_pc*lnpopden
	gen lngdp_pcsq_int=lngdp_pcsq*lnpopden
	
	gen deathcomb_extra=roaddeaths_irf
	replace deathcomb_extra=roaddeaths_unece if deathcomb_extra==.
	replace deathcomb_extra=roaddeaths_oecd if deathcomb_extra==.
	gen death_per100000_extra=deathcomb_extra/(10*pop)
	replace death_per100000_extra=deathcomb_extra/(population/100000) if death_per100000_extra==.
	gen lndeath_per100000_extra = ln(death_per100000_extra)
	gen rail_energy_share=energy_rail/energy_road_rail_air*100
	gen ln_airpass_pc=ln(airtransportpassengerscarried/(pop*1000000))
	gen lnalcohol_peradult=ln(alcohol_peradult)
	gen lnimr=ln(imr)
	
	*Road networks - interpolating
		bysort code: ipolate roadlength year, gen(networks1)
		gen lnnetworks1_pc = ln(networks1/population)
	
	*Paved road share - interpolating
	   bysort code: ipolate paved_share year, gen(paved1)
	   
	*Young population share - interpolating
		gen youngpop_1 = youngpop*1000
		bysort code: ipolate youngpop_1 year, gen(youngpop1)
		gen youngpopshare = (youngpop1/(1000000*pop))*100
		replace youngpopshare=(youngpop1/population)*100 if youngpopshare==.	
	 	
	*Setting sample
		sort code year
		qui xi: xtreg moto_share cars buses trucks lngdp_pc lnpopden i.year, fe cluster(cc)
		gen sample=1 if e(sample)
	
******************************************************************************************************
*TABLES
******************************************************************************************************
*TABLE 1
	preserve
	keep if year==2007
	drop if motorcycles==.
	drop if othermotorvehicles==.
	drop if population==.
	drop if cars==.	
	drop if buses==.
	drop if trucks==.
	codebook motorcycles popdensity	
	collapse (sum) motorcycles othermotorvehicles cars buses trucks population, by(income_group)
	gen mc_pthous=motorcycles/population*1000
	gen ve_pthous=othermotorvehicles/population*1000
	gen cars_pthous=cars/population*1000
	gen bus_pthous=buses/population*1000
	gen truck_pthous=trucks/population*1000
	gen mc_share=mc_pthous/(mc_pthous+ve_pthous)*100
	list income_group mc_pthous cars_pthous bus_pthous truck_pthous mc_share
	restore
	
	preserve
	keep if year==2007
	drop if motorcycles==.
	drop if othermotorvehicles==.
	drop if population==.
	drop if cars==.	
	drop if buses==.
	drop if trucks==.
	codebook motorcycles popdensity
	gen pop_d_high=0
	replace pop_d_high=1 if popdensity>=80.361
	collapse (sum) motorcycles othermotorvehicles cars buses trucks population, by(pop_d_high)
	gen mc_pthous=motorcycles/population*1000
	gen ve_pthous=othermotorvehicles/population*1000
	gen car_pth=cars/population*1000
	gen bus_pth=buses/population*1000
	gen truck_pthous=trucks/population*1000
	gen mc_share=mc_pthous/(mc_pthous+ve_pthous)*100
	list pop_d_high mc_pthous ve_pthous car_pth bus_pth truck_pthous mc_share
	collapse (sum) motorcycles othermotorvehicles cars buses trucks population
	gen mc_pthous_w=motorcycles/population*1000
	gen ve_pthous_w=othermotorvehicles/population*1000
	gen cars_pthous_w=cars/population*1000
	gen bus_pthous_w=buses/population*1000
	gen truck_pthous_w=trucks/population*1000
	gen mc_share_w=mc_pthous/(mc_pthous+ve_pthous)*100	
	list mc_pthous_w cars_pthous_w bus_pthous_w truck_pthous_w mc_share_w
	restore

	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="ETH" & year==2007
	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="BGD" & year==2007
	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="CHN" & year==2007
	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="THA" & year==2007
	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="DEU" & year==2007
	list moto_pth car_pth bus_pth trucks_pth moto_share if code=="USA" & year==2007
	
	preserve
	drop if motorcycles==.
	drop if othermotorvehicles==.
	drop if population==.
	drop if cars==.	
	drop if buses==.
	drop if trucks==.
	summ moto_pth car_pth bus_pth trucks_pth moto_share if year==2007
	summ moto_pth car_pth bus_pth trucks_pth moto_share if year==2007 & income_group=="Low income"
	summ moto_pth car_pth bus_pth trucks_pth moto_share if year==2007 & income_group=="Middle income"
	summ moto_pth car_pth bus_pth trucks_pth moto_share if year==2007 & income_group=="High income"
	restore
	
*TABLE 2
	*Specification A
		xi: xtreg lnmoto_pth lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_1
		
		xi: xtreg lnveh_pth lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_2
		
		xi: xtreg lncar_pth lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_3
		
		xi: xtreg lnbus_pth lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_4
		
		xi: xtreg lntrucks_pth lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_5
		
		xi: xtreg moto_share lngdp_pc lnpopden i.year if sample==1, fe cluster(cc)
		estimates store rega_6	
		xml_tab rega_1 rega_2 rega_3 rega_4 rega_5 rega_6, stats(r2 N N_g) below sheet("Table 2 Spec A") format(nTLR2) replace save(Nishitateno_Burke_2014)	 
	
	*Specification B
		xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_1
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		
		xi: xtreg lnveh_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_2
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		
		xi: xtreg lncar_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_3
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		
		xi: xtreg lnbus_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_4
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		
		xi: xtreg lntrucks_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_5
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		
		xi: xtreg moto_share lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
		estimates store regb_6	
		nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
		xml_tab regb_1 regb_2 regb_3 regb_4 regb_5 regb_6, stats(r2 N N_g) below sheet("Table 2 Spec B") format(nTLR2) append save(Nishitateno_Burke_2014)	 
			
	*Specification C
		xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_1
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		
		xi: xtreg lnveh_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_2
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		
		xi: xtreg lncar_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_3
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		
		xi: xtreg lnbus_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_4
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		
		xi: xtreg lntrucks_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_5
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		
		xi: xtreg moto_share lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
		estimates store regc_6	
		nlcom exp(-1*(_b[lngdp_pc]+4.19391*_b[lngdp_pc_int])/(2*(_b[lngdp_pcsq]+4.19391*_b[lngdp_pcsq_int])))
		xml_tab regc_1 regc_2 regc_3 regc_4 regc_5 regc_6, stats(r2 N N_g) below sheet("Table 2 Spec C") format(nTLR2) append save(Nishitateno_Burke_2014)	 	

*Table 3	
	xtreg lndeath_per100000_extra moto_share i.year if sample==1, fe cluster(cc)
	
	xtreg lndeath_per100000_extra moto_share lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
	nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
	
	xtreg lndeath_per100000_extra moto_share lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 lntotalveh_pth rail_energy_share ln_airpass_pc youngpopshare urban lnalcohol_peradult lnimr i.year if sample==1, fe cluster(cc)
	nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
	
	xtreg death_per100000_extra moto_pth car_pth bus_pth trucks_pth i.year if sample==1, fe cluster(cc)
	test _b[moto_pth]=_b[car_pth]
	test _b[moto_pth]=_b[bus_pth]
	test _b[moto_pth]=_b[trucks_pth]
	
	xtreg death_per100000_extra moto_pth car_pth bus_pth trucks_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1, fe cluster(cc)
	nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
	test _b[moto_pth]=_b[car_pth]
	test _b[moto_pth]=_b[bus_pth]
	test _b[moto_pth]=_b[trucks_pth]
	
	xtreg death_per100000_extra moto_pth car_pth bus_pth trucks_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 rail_energy_share ln_airpass_pc youngpopshare urban lnalcohol_peradult lnimr i.year if sample==1, fe cluster(cc)
	nlcom exp(-1*_b[lngdp_pc]/(2*_b[lngdp_pcsq]))
	test _b[moto_pth]=_b[car_pth]
	test _b[moto_pth]=_b[bus_pth]
	test _b[moto_pth]=_b[trucks_pth]	
	
******************************************************************************************************
*FIGURES
******************************************************************************************************
*Figure 1
	line death_per100000_extra year if code=="IND" & year>1962, ytitle("Road deaths per 100,000 population" "(solid black line)", margin(medium) size(medium)) ylabel(0(10)30, axis(1)) lcolor(black) lwidth(thick) || line moto_pth year if code=="IND" & year>1962, lcolor(red) lpattern(dash) lwidth(thick) ytitle("Motorcycles per '000 population" "(dashed red line)", axis(2) margin(medium) size(medium)) yaxis(2) ylabel(0(100)400, axis(2)) scheme(s1color) legend(off) xtitle("") text(25 1970 "{bf:Panel A: India}", size(medium)) saving(India, replace)
	line death_per100000_extra year if code=="MYS" & year>1962, ytitle("Road deaths per 100,000 population" "(solid black line)", margin(medium) size(medium)) ylabel(0(10)30, axis(1)) lcolor(black) lwidth(thick) || line moto_pth year if code=="MYS" & year>1962, lcolor(red) lpattern(dash) lwidth(thick) ytitle("Motorcycles per '000 population" "(dashed red line)", axis(2) margin(medium) size(medium)) yaxis(2) ylabel(0(100)400, axis(2)) scheme(s1color) legend(off) xtitle("") text(25 1970 "{bf:Panel B: Malaysia}", size(medium)) saving(Malaysia, replace)
	
*Figure 2
	merge m:m code using auxil.dta
	gen rgdp_pc=1000000*rgdpe/(pop*1000000)
	replace rgdp_pc=auxiliary if rgdp_pc==.
	replace lngdp_pc=ln(rgdp_pc) if lngdp_pc==.
	replace lngdp_pcsq=lngdp_pc^2 if lngdp_pcsq==.
	codebook lnpopden if sample==1
	gen lngdp_pc_int_median=lngdp_pc*4.31041
	gen lngdp_pcsq_int_median=lngdp_pcsq*4.31041
	gen lngdp_pc_int_mean=lngdp_pc*4.19391
	gen lngdp_pcsq_int_mean=lngdp_pcsq*4.19391
	gen lngdp_pc_int_75p=lngdp_pc*5.06797 
	gen lngdp_pcsq_int_75p=lngdp_pcsq*5.06797 
	gen lngdp_pc_int_90p=lngdp_pc*5.91603
	gen lngdp_pcsq_int_90p=lngdp_pcsq*5.91603	
	
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
	gen moto_pth_pr_90p=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*5.91603+_b[lngdp_pc_int]*lngdp_pc_int_90p+_b[lngdp_pcsq_int]*lngdp_pcsq_int_90p+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen moto_pth_pr_median=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.31041+_b[lngdp_pc_int]*lngdp_pc_int_median+_b[lngdp_pcsq_int]*lngdp_pcsq_int_median+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen moto_pth_pr_mean=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.19391+_b[lngdp_pc_int]*lngdp_pc_int_mean+_b[lngdp_pcsq_int]*lngdp_pcsq_int_mean+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
			
	xi: xtreg lncar_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
	gen car_pth_pr_median=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.31041+_b[lngdp_pc_int]*lngdp_pc_int_median+_b[lngdp_pcsq_int]*lngdp_pcsq_int_median+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen car_pth_pr_90p=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*5.91603+_b[lngdp_pc_int]*lngdp_pc_int_90p+_b[lngdp_pcsq_int]*lngdp_pcsq_int_90p+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen car_pth_pr_mean=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.19391+_b[lngdp_pc_int]*lngdp_pc_int_mean+_b[lngdp_pcsq_int]*lngdp_pcsq_int_mean+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
		
	xi: xtreg lnbus_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
	gen bus_pth_pr_median=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.31041+_b[lngdp_pc_int]*lngdp_pc_int_median+_b[lngdp_pcsq_int]*lngdp_pcsq_int_median+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen bus_pth_pr_90p=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*5.91603+_b[lngdp_pc_int]*lngdp_pc_int_90p+_b[lngdp_pcsq_int]*lngdp_pcsq_int_90p+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen bus_pth_pr_mean=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.19391+_b[lngdp_pc_int]*lngdp_pc_int_mean+_b[lngdp_pcsq_int]*lngdp_pcsq_int_mean+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
			
	xi: xtreg lntrucks_pth lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
	gen truck_pth_pr_median=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.31041+_b[lngdp_pc_int]*lngdp_pc_int_median+_b[lngdp_pcsq_int]*lngdp_pcsq_int_median+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen truck_pth_pr_90p=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*5.91603+_b[lngdp_pc_int]*lngdp_pc_int_90p+_b[lngdp_pcsq_int]*lngdp_pcsq_int_90p+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
	gen truck_pth_pr_mean=exp(_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.19391+_b[lngdp_pc_int]*lngdp_pc_int_mean+_b[lngdp_pcsq_int]*lngdp_pcsq_int_mean+_b[_Iyear_2010]+_b[_cons])*exp(e(rmse)^2/2)
			
	twoway (line car_pth_pr_mean bus_pth_pr_mean truck_pth_pr_mean moto_pth_pr_mean lngdp_pc, lwidth(thick thick thick thick) lpattern(dash dot dash_dot solid) lcolor(blue green gray black)) if code=="AUX", text(26 9.75 "Motorcycles", place(ne)) text(180 9.28 "Cars", place(ne) color(blue)) text(5.1 9 "Buses", place(ne) color(green)) text(55 10 "Trucks", place(ne) color(gray)) legend(off) xtitle("Log GDP per capita", margin(medium)) ytitle("Vehicles per thousand population", margin(medium)) ylabel(0(50)300) yscale(range(0 300)) xlabel(5(2)11) xscale(range(5 11)) scheme(s1color) 
	
*Figure 3
	twoway (line moto_pth_pr_mean moto_pth_pr_90p lngdp_pc, lwidth(thick thick) lpattern(solid dash) lcolor(black gray)) if code=="AUX" & moto_pth_pr_median>0 & moto_pth_pr_90p>0, text(28 8.7 "Mean", place(ne) color(black)) text(180 5.85 "90th-percentile population density", place(ne) color(gray)) xtitle("Log GDP per capita", margin(medium)) legend(off) ytitle("Motorcycles per thousand population", margin(medium)) ylabel(0(50)200) yscale(range(0 200)) xlabel(5(2)11) xscale(range(5 11)) scheme(s1color) 

*Figure 4
	xi: xtreg moto_share lngdp_pc lngdp_pcsq lnpopden lngdp_pc_int lngdp_pcsq_int i.year if sample==1, fe cluster(cc)
	
	gen moto_share_pr_mean=_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.19391+_b[lngdp_pc_int]*lngdp_pc_int_mean+_b[lngdp_pcsq_int]*lngdp_pcsq_int_mean+_b[_Iyear_2010]+_b[_cons]
	gen moto_share_pr_90p=_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*5.91603+_b[lngdp_pc_int]*lngdp_pc_int_90p+_b[lngdp_pcsq_int]*lngdp_pcsq_int_90p+_b[_Iyear_2010]+_b[_cons]
	gen moto_share_pr_median=_b[lngdp_pc]*lngdp_pc+_b[lngdp_pcsq]*lngdp_pcsq+_b[lnpopden]*4.31041+_b[lngdp_pc_int]*lngdp_pc_int_median+_b[lngdp_pcsq_int]*lngdp_pcsq_int_median+_b[_Iyear_2010]+_b[_cons]

	twoway (line moto_share_pr_mean moto_share_pr_90p lngdp_pc, lwidth(thick thick) lpattern(solid dash) lcolor(black gray)) if code=="AUX" & moto_share_pr_median>0 & moto_share_pr_90p>0, text(26 8 "Mean", place(ne) color(black)) text(59 8 "90th-percentile population density", place(ne) color(gray)) xtitle("Log GDP per capita", margin(medium)) legend(off) ytitle("Motorcycle share of all motor vehicles (%)", margin(medium)) ylabel(0(20)100) yscale(range(0 100)) xlabel(5(2)11) xscale(range(5 11)) scheme(s1color) 
	drop if code=="AUX"
	
******************************************************************************************************
*OTHER POINTS MENTIONED IN TEXT
******************************************************************************************************
*What share of global population?
	bysort country: egen dummy=max(sample)
	bysort year: egen populationsum_10=sum(population) if year==2010 & dummy==1
	codebook dummy populationsum_10 if year==2010 & dummy==1
	gen pop_share_10=populationsum_10/6885217727
	codebook pop_share_10 if year==2010
	sort code year

*Excluding countries with suspicious data observations
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & code~="ESP" & code~="GRC" & code~="JPN" & code~="KOR" & code~="LUX" & code~="PRT" & code~="SWE", fe cluster(cc)

*Urban population interactions
	gen urbanlngdp_pc=lngdp_pc*urban
	gen urbanlngdp_pcsq=lngdp_pcsq*urban
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq urban urbanlngdp_pc urbanlngdp_pcsq i.year if sample==1, fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq urban i.year if sample==1, fe cluster(cc)

*Temperature interactions
	gen temp_2000_1=temperature if year==2000
	bysort code: egen temp_2000=max(temp_2000)
	gen temp_lngdp_pc=temp_2000*lngdp_pc
	gen temp_lngdp_pcsq=temp_2000*lngdp_pcsq
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq temp_lngdp_pc temp_lngdp_pcsq i.year if sample==1, fe cluster(cc)
	sort code year

*Excluding regions
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="East Asia & Pacific", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="Europe & Central Asia", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="Latin America & Caribbean", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="Middle East & North Africa", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="North America", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="South Asia", fe cluster(cc)
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden i.year if sample==1 & region~="Sub-Saharan Africa", fe cluster(cc)

*Vehicle regressions with additional controls
	xi: xtreg lnmoto_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)
	xi: xtreg lnveh_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)
	xi: xtreg lncar_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)
	xi: xtreg lnbus_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)
	xi: xtreg lntrucks_pth lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)
	xi: xtreg moto_share lngdp_pc lngdp_pcsq lnpopden lnnetworks1_pc paved1 youngpopshare urban i.year if sample==1, fe cluster(cc)

*Cross-sectional road death estimates
	reg death_per100000_extra moto_pth car_pth bus_pth trucks_pth lngdp_pc lngdp_pcsq lnpopden bac if sample==1 & year==2009, r
	reg death_per100000_extra moto_pth car_pth bus_pth trucks_pth lngdp_pc lngdp_pcsq lnpopden bac if sample==1 & year==2008, r

*Country-by-country time trends
	tab cc, gen(icc)
	*generate country time trend*
	local i=1
	while (`i'<157){		
	quietly gen iccyear`i' = icc`i'*year
	label variable iccyear`i' "Country-Specific Time Trend for cc`i'"
	local i = `i' + 1
	}	
	xtreg death_per100000_extra moto_pth car_pth bus_pth trucks_pth lngdp_pc lngdp_pcsq iccyear* lnpopden lnnetworks1_pc paved1 rail_energy_share ln_airpass_pc youngpopshare urban lnalcohol_peradult lnimr if sample==1, fe cluster(cc)
